@@ -1,6 +1,6 @@
 package CPAN::Perl::Releases;
 {
-  $CPAN::Perl::Releases::VERSION = '0.96';
+  $CPAN::Perl::Releases::VERSION = '0.98';
 }
 
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
@@ -236,6 +236,10 @@ our $data =
     "tar.bz2" => "D/DO/DOM/perl-5.14.3.tar.bz2",
     "tar.gz" => "D/DO/DOM/perl-5.14.3.tar.gz",
   },
+  "5.14.4-RC1" => {
+    "tar.bz2" => "D/DA/DAPM/perl-5.14.4-RC1.tar.bz2",
+    "tar.gz" => "D/DA/DAPM/perl-5.14.4-RC1.tar.gz",
+  },
   "5.15.0" => {
     "tar.bz2" => "D/DA/DAGOLDEN/perl-5.15.0.tar.bz2",
     "tar.gz" => "D/DA/DAGOLDEN/perl-5.15.0.tar.gz",
@@ -455,7 +459,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 0.96
+version 0.98
 
 =head1 SYNOPSIS
 
